@@ -1658,7 +1658,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
 
   int direction; /* either +1 or -1 -- are we looking for a bigger font
 		    or a smaller one? */
-
+#if 0
   g_return_val_if_fail (unsized_name, NULL);
   g_return_val_if_fail (gnome_font, NULL);
   g_return_val_if_fail (x_font_name_ret, NULL);
@@ -1667,9 +1667,10 @@ static GdkFont *find_best_x_font (char *unsized_name,
   /*space_width = gnome_font_get_width_string (gnome_font, " ");*/
   /*max_width = perfect_width + space_width / 2;*/
   max_width = perfect_width /*- 1*/;
-
-  current_size = (int) (gnome_font->size * 10);
-  current_x_name = setFontPointSize (unsized_name, current_size);
+  g_print( "perfect_width = %f\n", perfect_width );
+#endif
+  current_size = (int) (gnome_font->size);
+  current_x_name = setFontPixelSize (unsized_name, current_size);
   current_font = find_best_x_weight (current_x_name, gnome_font->fontmap_entry->weight_code);
 
   /* start by getting some x font loaded */
@@ -1709,6 +1710,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
 
   printf ("initial name loaded: '%s'\n", current_x_name);
 
+#if 0
   current_width = gdk_text_width (current_font, test_string, length);
   current_diff = (int) (perfect_width - current_width);
 
@@ -1719,7 +1721,6 @@ static GdkFont *find_best_x_font (char *unsized_name,
   if (current_diff > 0) direction = 1;
   else direction = -1;
   */
-
   if (current_diff > 0)
     {
       /*direction = (int) gnome_font->size / 6.0;*/
@@ -1739,7 +1740,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
   while (current_diff != 0)
     {
       int next_size = current_size + direction;
-      char *next_x_name = setFontPointSize (current_x_name, next_size);
+      char *next_x_name = setFontPixelSize (current_x_name, next_size);
       GdkFont *next_font = find_best_x_weight (next_x_name, gnome_font->fontmap_entry->weight_code);
       int next_width;
       int next_diff;
@@ -1768,7 +1769,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
 	  break;
 	}
 
-      free (current_x_name);
+      g_free (current_x_name);
       gdk_font_unref (current_font);
 
       current_size = next_size;
@@ -1778,7 +1779,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
 
       printf (" new size=%d, new diff=%d\n", current_size, current_diff);
     }
-
+#endif
   (*x_font_name_ret) = current_x_name;
   return current_font;
 }
@@ -1794,18 +1795,21 @@ static GnomeDisplayFont *create_display_font (char *family,
 					      double scale)
 {
   char *x_family;
-  char *xfn = strdup ("-*-helvetica-*-r-*-*-*-10-*-*-*-*-*-*");
+  char *xfn = g_strdup ("-*-helvetica-*-r-*-*-12-*-*-*-*-*-*-*");
   GnomeFontUnsized *gfus;
-  GnomeFont *gnome_font;
+  GnomeFont *gnome_font, *closest;
   GnomeDisplayFont *wpdf;
 
   g_return_val_if_fail (family, NULL);
 
   if (! scaled_display_fonts) initialize_hashes ();
 
-  gfus = gnome_font_new_closest (family, weight, italic, 0)->fontmap_entry;
+  if ((closest = gnome_font_new_closest (family, weight, italic, 0)) == NULL)
+	  return NULL;
+	
+  gfus = closest->fontmap_entry;
   gnome_font = gnome_font_new_closest (family, weight, italic, points * scale);
-  wpdf = (GnomeDisplayFont *) malloc (sizeof (GnomeDisplayFont));
+  wpdf = (GnomeDisplayFont *) g_malloc (sizeof (GnomeDisplayFont));
 
   wpdf->unsized_font = gfus;
   wpdf->gnome_font = gnome_font;
@@ -1821,7 +1825,7 @@ static GnomeDisplayFont *create_display_font (char *family,
   wpdf->gdk_font =
     find_best_x_font (xfn, wpdf->gnome_font, &(wpdf->x_font_name));
 
-  free (xfn);
+  g_free (xfn);
 
   g_return_val_if_fail (wpdf->gdk_font, NULL);
   return wpdf;
@@ -1859,7 +1863,7 @@ GnomeDisplayFont *gnome_get_display_font (char *family,
     {
       wpdf = create_display_font (family, weight, italic, points, scale);
       g_return_val_if_fail (wpdf, NULL);
-      g_hash_table_insert (scaled_display_fonts, strdup (key), wpdf);
+      g_hash_table_insert (scaled_display_fonts, g_strdup (key), wpdf);
     }
 
   return wpdf;
@@ -1913,9 +1917,9 @@ char *getFontComponent (char *font_name, unsigned int pos)
     }
 
   if (font_name == NULL || strcmp (font_name, "") == 0)
-    return strdup ("*");
+    return g_strdup ("*");
 
-  scratch = strdup (font_name);
+  scratch = g_strdup (font_name);
 
   for (i=0, p=scratch+1; i<14 && *p != '\0'; i++)
     {
@@ -1926,8 +1930,8 @@ char *getFontComponent (char *font_name, unsigned int pos)
       p ++;
     }
 
-  ret = strdup (parts[ pos ]);
-  free (scratch);
+  ret = g_strdup (parts[ pos ]);
+  g_free (scratch);
 
   return ret;
 }
@@ -1944,15 +1948,15 @@ char *setFontComponent (char *font_name, unsigned int pos, char *s)
     {
       fprintf (stderr, "replaceFontComponent -- pos out of ");
       fprintf (stderr, "range: %d\n", pos);
-      return strdup (font_name);
+      return g_strdup (font_name);
     }
 
   if (font_name != NULL && *font_name != '\0')
-    scratch = strdup (font_name);
+    scratch = g_strdup (font_name);
   else
     {
       char *d = "-*-*-*-*-*-*-*-*-*-*-*-*-*-*";
-      scratch = strdup (d);
+      scratch = g_strdup (d);
     }
 
   for (i=0, p=scratch+1; i<14 && (*p) != '\0'; i++)
@@ -1972,7 +1976,7 @@ char *setFontComponent (char *font_name, unsigned int pos, char *s)
   for (i=0, len=0; i<14; i++)
     len += strlen (parts[ i ]);
 
-  new_name = (char *) malloc (len + 17);
+  new_name = (char *) g_malloc (len + 17);
 
   sprintf(new_name, "-%s-%s-%s-%s-%s-%s-%s-%s-%s-%s-%s-%s-%s-%s",
 	  parts[ 0 ], parts[ 1 ], parts[ 2 ], parts[ 3 ], 
@@ -1980,7 +1984,7 @@ char *setFontComponent (char *font_name, unsigned int pos, char *s)
 	  parts[ 8 ], parts[ 9 ], parts[ 10 ], parts[ 11 ],
 	  parts[ 12 ], parts[ 13 ]);
 
-  free (scratch);
+  g_free (scratch);
   return new_name;
 }
 
@@ -2004,7 +2008,7 @@ GnomeFontWeight getGnomeFontWeight (char *font_name)
 {
   char *weight = getFontComponent (font_name, 2);
   GnomeFontWeight fw = string_to_gnome_font_weight (weight);
-  free (weight);
+  g_free (weight);
   return fw;
 }
 
@@ -2022,7 +2026,7 @@ gboolean fontIsItalic (char *font_name)
   else if (strcasecmp (slant, "o") == 0) s = TRUE;
   else if (strcasecmp (slant, "r") == 0) s = FALSE;
 
-  free (slant);
+  g_free (slant);
   return s;
 }
 
@@ -2041,7 +2045,7 @@ int getFontPixelSize (char *font_name)
   int ret;
   char *p = getFontComponent (font_name, 6);
   ret = atoi (p);
-  free (p);
+  g_free (p);
   return ret;
 }
 
@@ -2050,7 +2054,7 @@ int getFontPointSize (char *font_name)
   int ret;
   char *p = getFontComponent (font_name, 7);
   ret = atoi (p);
-  free (p);
+  g_free (p);
   return ret;
 }
 
@@ -2059,7 +2063,7 @@ int getFontResolutionX (char *font_name)
   int ret;
   char *p = getFontComponent (font_name, 8);
   ret = atoi (p);
-  free (p);
+  g_free (p);
   return ret;
 }
 
@@ -2068,7 +2072,7 @@ int getFontResolutionY (char *font_name)
   int ret;
   char *p = getFontComponent (font_name, 9);
   ret = atoi (p);
-  free (p);
+  g_free (p);
   return ret;
 }
 
@@ -2082,7 +2086,7 @@ int getFontAverageWidth (char *font_name)
   int ret;
   char *p = getFontComponent (font_name, 11);
   ret = atoi (p);
-  free (p);
+  g_free (p);
   return ret;
 }
 
@@ -2199,6 +2203,6 @@ static void setComponentReplace (char **io,
 				 char *part)
 {
   char *new_name = (*func) (*io, part);
-  free (*io);
+  g_free (*io);
   (*io) = new_name;
 }
